[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kmail-devel
Subject:    [PATCH] For Grave KMail Bug in KDE 3.5.6
From:       Allen Winter <winter () kde ! org>
Date:       2007-01-27 15:22:27
Message-ID: 200701271022.27815.winter () kde ! org
[Download RAW message or body]

Howdy Packagers,

Attached is a patch for bug #140660 http://bugs.kde.org/show_bug.cgi?id=140660
This is a grave KMail bug for 3.5.6.

Also attached is a patch for a bug in the new KMail templates feature.

I ask you to push out these updates for your distributions.
Regards,
Allen

-- 
KDEPIM Developer
I accept PayPal payments to awinterz@earthlink.net

["kmail-140660.patch" (text/x-diff)]

Index: kmfolder.cpp
===================================================================
--- kmfolder.cpp	(revision 627528)
+++ kmfolder.cpp	(working copy)
@@ -426,12 +426,12 @@ int KMFolder::moveMsg(QPtrList<KMMessage
 
 int KMFolder::find( const KMMsgBase* msg ) const
 {
-  return mStorage->find( msg );
+  return mStorage ? mStorage->find( msg ) : 0;
 }
 
 int KMFolder::find( const KMMessage* msg ) const
 {
-  return mStorage->find( msg );
+  return mStorage ? mStorage->find( msg ) : 0;
 }
 
 int KMFolder::count( bool cache ) const

["kmail-templates.patch" (text/x-diff)]

--- branches/KDE/3.5/kdepim/kmail/kmfolder.cpp	2006/10/28 17:04:18	599816
+++ branches/KDE/3.5/kdepim/kmail/kmfolder.cpp	2007/01/27 00:32:53	627548
@@ -631,11 +631,13 @@
         mWhoField = "From";
       if ( this == kmkernel->outboxFolder() ||
            this == kmkernel->sentFolder() ||
-           this == kmkernel->draftsFolder() )
+           this == kmkernel->draftsFolder() ||
+           this == kmkernel->templatesFolder() )
         mWhoField = "To";
-    } else if ( identity.drafts() == idString()
-                || identity.fcc() == idString() )
-      // drafts or sent of the identity
+    } else if ( identity.drafts() == idString() ||
+                identity.templates() == idString() ||
+                identity.fcc() == idString() )
+      // drafts, templates or sent of the identity
       mWhoField = "To";
     else
       mWhoField = "From";


_______________________________________________
KMail developers mailing list
KMail-devel@kde.org
https://mail.kde.org/mailman/listinfo/kmail-devel


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic